# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Territory Design toolbox provides a set of tools to build, edit,
balance, and maintain territories for point and polygon datasets."""
__all__ = ['AddLevelVariables', 'AddTerritoryLevel', 'CreateTerritorySolution',
           'ImportTerritorySolution', 'LoadTerritoryRecords',
           'SetBalanceVariables', 'SolveTerritories']
__alias__ = 'td'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analysis toolset
@gptooldoc('AddLevelVariables_td', None)
def AddLevelVariables(in_territory_solution=None, level=None, base_level=None, variables=None):
    """AddLevelVariables_td(in_territory_solution, level, base_level, variables;variables...)

        Adds a new field at the specified level. The field will be based on a
        numeric field from the level below the territory level and will be
        calculated based on the type of statistic specified by the user.

     INPUTS:
      in_territory_solution (Group Layer / Feature Dataset / String):
          Input territory solution.
      level (String):
          Level to which the calculated field will be added.
      base_level (String):
          Level below the territory level from which the attribute value will be
          added.
      variables (Value Table):
          The variables that will be added to the level.

          * statistic_field-Field for statistical calculation.

          * statistic-Type of statistical calculation.

          * count-Employs count in the derivation of the statistical
          calculation.

          * sum-Employs summation in the derivation of the statistical
          calculation.

          * maximum-Employs maximum value in the derivation of the statistical
          calculation.

          * minimum-Employs minimum value in the derivation of the statistical
          calculation.

          * average-Employs average in the derivation of the statistical
          calculation.

          * median-Employs the use of median techniques in the derivation of the
          statistical calculation.

          * standard_deviation-Employs standard deviation in the derivation of
          the statistical calculation.

          * percent_of_total-Employs percentage techniques in the derivation of
          the statistical calculation.

          * field_name-Valid name of the field on the level where calculated
          data will be stored.

          * field_alias_name-Readable and understandable name of the calculated
          field."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddLevelVariables_td(*gp_fixargs((in_territory_solution, level, base_level, variables), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetBalanceVariables_td', None)
def SetBalanceVariables(in_territory_solution=None, level=None, variables=None):
    """SetBalanceVariables_td(in_territory_solution, level, {variables;variables...})

        Configures variables to be used in the balancing process. The
        variables will be used according to relative weight, which is
        calculated based on a specified preference for each variable.

     INPUTS:
      in_territory_solution (Group Layer / Feature Dataset / String):
          Name of the input territory solution.
      level (String):
          Name of the level to which the calculated field will be added.
      variables {Value Table}:
          Variables that will be used in the balance process.

          * variable-The defined input.

          * preference (%)-The weight given in the analysis."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetBalanceVariables_td(*gp_fixargs((in_territory_solution, level, variables), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SolveTerritories_td', None)
def SolveTerritories(in_territory_solution=None, level=None, method=None, number_territories=None):
    """SolveTerritories_td(in_territory_solution, level, method, {number_territories})

        Creates and balances territories on the specified territory level
        provided the balancing variables are set.

     INPUTS:
      in_territory_solution (Group Layer / Feature Dataset / String):
          Territory solution used to solve territories.
      level (String):
          Level used to solve territories.
      method (String):
          Indicates how the number of territories is determined. The default is
          USER_DEFINED.
      number_territories {Long}:
          Number of territories to be specified."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SolveTerritories_td(*gp_fixargs((in_territory_solution, level, method, number_territories), True)))
        return retval
    except Exception as e:
        raise e


# Territory Solution toolset
@gptooldoc('AddTerritoryLevel_td', None)
def AddTerritoryLevel(in_territory_solution=None, level_name=None, default_territory_name=None):
    """AddTerritoryLevel_td(in_territory_solution, level_name, {default_territory_name})

        Creates a new empty feature class to represent a level.

     INPUTS:
      in_territory_solution (Group Layer / Feature Dataset / String):
          The input territory solution.
      level_name (String):
          The name of the new territory level.
      default_territory_name {String}:
          The name to be used as a prefix for new territories that will be
          created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTerritoryLevel_td(*gp_fixargs((in_territory_solution, level_name, default_territory_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateTerritorySolution_td', None)
def CreateTerritorySolution(in_features=None, solution_name=None, id_field=None, name_field=None, territory_level_name=None, default_territory_name=None):
    """CreateTerritorySolution_td(in_features, solution_name, {id_field}, {name_field}, {territory_level_name}, {default_territory_name})

        Creates a new territory solution with two levels and loads input
        features into the base level.The type of input layer determines how
        the base level is displayed
        (for example, points or polygons). Additional geometries can be
        created to display either boundary centers or polygon boundaries.

     INPUTS:
      in_features (Feature Layer):
          The geometry or data features that will be used as the base level of
          the created solution. The level will have the same name as the input
          features.
      solution_name (String):
          The name of the territory solution to be created.
      id_field {Field}:
          The field that contains ID values for objects in the level.
      name_field {Field}:
          The field that contains name values for objects in the level.
      territory_level_name {String}:
          The name of the territory level (level 2).
      default_territory_name {String}:
          The prefix for the names of the new territories that will be
          created-for example, Territory 1, Territory 2, and Territory 3 or
          District 1, District 2, and District 3."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateTerritorySolution_td(*gp_fixargs((in_features, solution_name, id_field, name_field, territory_level_name, default_territory_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportTerritorySolution_td', None)
def ImportTerritorySolution(in_data=None, solution_name=None, level_settings=None):
    """ImportTerritorySolution_td(in_data, solution_name, level_settings;level_settings...)

        Creates a new territory solution and imports the territories
        hierarchy from a table or a layer.

     INPUTS:
      in_data (Table View):
          The layer or records to be imported.
      solution_name (String):
          The name of the territory solution to be created.
      level_settings (Value Table):
          The level settings for importing the territories hierarchy.

          * level_name-The name of the level (required).

          * default_territory_name-The prefix for the new territories that will,
          subsequently, be created at the level (optional).

          * id_field-The field that contains IDs (unique IDs) for territories
          (required).

          * name_field-The field that contains names for territories (optional).

          * parent_id_field-The field that contains IDs of parent territories
          (optional).

          * primary_geometry-Specifies the class level that will be used for
          storing level attributes (optional).

          * TERRITORY_BOUNDARIES-Level attributes will be stored using the
          boundaries of the territory solution.

          * TERRITORY_CENTERS-Level attributes will be stored using the boundary
          centers of the territory solution.

          * BASE_BOUNDARIES-Level attributes will be stored using the boundaries
          of the base layer.

          * BASE_CENTERS-Level attributes will be stored using the boundary
          centers of the base layer."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportTerritorySolution_td(*gp_fixargs((in_data, solution_name, level_settings), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LoadTerritoryRecords_td', None)
def LoadTerritoryRecords(in_territory_solution=None, level=None, in_data=None, id_field=None, name_field=None, field_map=None, append_data=None):
    """LoadTerritoryRecords_td(in_territory_solution, level, in_data, {id_field}, {name_field}, {field_map;field_map...}, {append_data})

        Adds records (features) or updates existing records for the specified
        level.

     INPUTS:
      in_territory_solution (Group Layer / Feature Dataset / String):
          The input territory solution.
      level (String):
          The level where the data will be loaded.
      in_data (Table View):
          The layer or records to be loaded.
      id_field {Field}:
          The field containing ID values to be loaded into the level.
      name_field {Field}:
          The field containing name values to be loaded into the level.
      field_map {Value Table}:
          Sets the values for the territory.attribute-The special attribute.

          * PARENT_TERRITORY_ID-The ID of the parent territory.

          * LOCKED_STATE-Boundary can't be modified.

          * CENTER_LOCKED-Center points can't be modified and will remain in
          their fixed locations.
          field-The input data field that contains data for the special
          attribute.
      append_data {Boolean}:
          Specifies where to append or replace the records being loaded.

          * APPEND-Appends records to the specified level.

          * REPLACE-Replaces records to the specified level. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LoadTerritoryRecords_td(*gp_fixargs((in_territory_solution, level, in_data, id_field, name_field, field_map, append_data), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject